/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2001 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Axis" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.apache.axis.async;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.naming.NamingException;
import javax.naming.Reference;
import javax.naming.Referenceable;
import javax.xml.namespace.QName;
import java.io.Serializable;
import java.net.URL;

/**
 * The AxisConnectionFactory is used to create AxisConnection instances.  It can be stored in
 * a JNDI repository for lookup in an app server or other directory-enabled environments.  The
 * configurable options are WSDL location and Service QName.  These are default values.  If the
 * default values are not given, the AxisConnectionFactory provides a mechanism to set these
 * parameters on an individual connection basis using the factory methods.
 *
 * @author Jaime Meritt <jmeritt@sonicsoftware.com>
 */
public class AxisConnectionFactory implements ConnectionFactory, Serializable, Referenceable
{
    /**
     * Creates a connection to a particular service.  Will use the defaults for
     * WSDL location and service QName if they are provided.  This is an insecure
     * connection.
     * @return a new connection instance to a web service
     * @throws javax.jms.JMSException
     */
    public Connection createConnection() throws javax.jms.JMSException
    {
        return null;
    }

    /**
     * Creates a connection to a particular service.  Will use the defaults for
     * WSDL location and service QName if they are provided.  This is an insecure
     * connection.
     * @return a new connection instance to a web service
     * @param username
     * @param password
     * @throws javax.jms.JMSException
     */
    public Connection createConnection(String username, String password) throws javax.jms.JMSException
    {
        return null;
    }

    /**
     * Creates a connection to a particular service.  Will use the defaults for
     * WSDL location and service QName if they are provided.  This is an insecure
     * connection.
     * @return a new connection instance to a web service
     * @param wsdlLocation
     * @param service
     * @throws javax.jms.JMSException
     */
    public AxisConnection createConnection(URL wsdlLocation, QName service) throws javax.jms.JMSException
    {
        return null;
    }

    /**
     * Creates a connection to a particular service.  Will use the defaults for
     * WSDL location and service QName if they are provided.  This is an insecure
     * connection.
     * @return a new connection instance to a web service
     * @param wsdlLocation
     * @param service
     * @param username
     * @param password
     * @throws javax.jms.JMSException
     */
    public AxisConnection createConnection(URL wsdlLocation, QName service,
                                           String username, String password) throws javax.jms.JMSException
    {
        return null;
    }

    /**
     * gets a reference to the resource as defined in the JNDI specification
     * @return a reference to the resource
     * @throws NamingException if the resource cannot be created for any reason.
     */
    public Reference getReference() throws NamingException
    {
        throw new java.lang.UnsupportedOperationException("Method getReference() not yet implemented.");
    }

    /**
     * sets the WSDL location default
     * @param wsdlLocation the location of the WSDL document
     */
    public void setWsdlLocation(URL wsdlLocation)
    {
        this.wsdlLocation = wsdlLocation;
    }

    /**
     * gets the WSDL location default value
     * @return the default WSDL location
     */
    public java.net.URL getWsdlLocation()
    {
        return wsdlLocation;
    }

    /**
     * sets the default QName for connections created through this factory
     * @param service the QName
     */
    public void setService(QName service)
    {
        this.service = service;
    }

    /**
     * gets the default QName for connections created through this factory
     * @return the QName for the default service
     */
    public QName getService()
    {
        return service;
    }

    private URL wsdlLocation;
    private QName service;

}