/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2001 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Axis" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */
package samples.async;

import org.apache.axis.async.AxisConnection;
import org.apache.axis.async.AxisConnectionFactory;
import org.apache.axis.async.AxisSession;
import org.apache.axis.async.SAAJMessage;

import javax.jms.Session;
import javax.jms.Destination;
import javax.jms.MessageProducer;
import javax.jms.JMSException;
import javax.xml.soap.*;
import java.net.URL;
import java.net.MalformedURLException;

/**
 * This example uses the raw SAAJ APIs to construct a SAAJMessage and send
 * it to the appropriate destination.  This is the way that most JAXM
 * users would use the API.
 *
 * @author Jaime Meritt <jmeritt@sonicsoftware.com>
 */
public class SAAJExample
{

    public static void main(String[] args) throws JMSException, MalformedURLException, SOAPException
    {
        String sendURL = args[0];
        AxisConnection conn = (AxisConnection) new AxisConnectionFactory().createConnection();

        AxisSession sendSession = (AxisSession) conn.createSession(false, Session.DUPS_OK_ACKNOWLEDGE);

        Destination sendAddress = sendSession.createDestination(new URL(sendURL));
        MessageProducer producer = sendSession.createProducer(sendAddress);

        SAAJMessage message = sendSession.createSAAJMessage();
        SOAPPart part = message.getSOAPPart();
        SOAPEnvelope envelope = part.getEnvelope();
        SOAPFactory factory = SOAPFactory.newInstance();
        SOAPBody body = envelope.addBody();
        SOAPElement bodyElement = body.addBodyElement(factory.createName("PO", "po", "uri:purchasing"));
        bodyElement.addTextNode("I want to buy a car");
        message.saveChanges();
        producer.send(message);
        conn.close();
    }
}
