/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2001 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Axis" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */
package samples.async;

import org.apache.axis.async.*;

import javax.jms.*;
import java.net.URL;

/**
 * This examples demonstrates the use of the asynchronous client API to
 * support solicit/response and notification style web service operations.
 *
 * @author Jaime Meritt <jmeritt@sonicsoftware.com>
 */
public class SolicitResponseExample implements MessageListener
{
    AxisConnection m_connection;
    MessageProducer m_producer;
    AxisSession m_session;

    public SolicitResponseExample(URL receiveURL) throws JMSException
    {
        AxisConnectionFactory factory = new AxisConnectionFactory();
        m_connection = (AxisConnection) factory.createConnection();
        m_session = (AxisSession) m_connection.createSession(false, Session.DUPS_OK_ACKNOWLEDGE);
        //this creates an unbound producer that can be used to return responses
        m_producer = m_session.createProducer(null);
        MessageConsumer consumer = m_session.createConsumer(m_session.createDestination(receiveURL));
        consumer.setMessageListener(this);
        m_connection.start();
    }

    public static void main(String[] args) throws Exception
    {
        String receiveURL = args[1];
        SolicitResponseExample example = new SolicitResponseExample(new URL(receiveURL));
        Thread.sleep(10000);
        example.close();
    }

    private void close() throws JMSException
    {
        m_connection.close();
    }

    public void onMessage(Message message)
    {
        try
        {
            AxisMessage auctionListing = (AxisMessage) message;
            Object[] params = auctionListing.getValues().toArray();
            String item = (String) params[0];
            float price = ((Float) params[1]).floatValue();
            if (isItemWorthIt(item))
            {
                System.out.println("Bidding on " + item);
                AxisMessage bid = m_session.createAxisMessage(new Float(price + 5));
                bid.setCorrelatedMessage(auctionListing);
                Destination replyTo = auctionListing.getJMSReplyTo();
                m_producer.send(replyTo, bid);
            }
            else
            {
                System.out.println("Passing on " + item);
            }

        }
        catch (JMSException e)
        {
            e.printStackTrace();
        }
    }

    private boolean isItemWorthIt(String item)
    {
        return item.equalsIgnoreCase("A NEW CAR");
    }
}
